@@ -136,11 +136,15 @@ parse_group (char *name, int *g)
       unsigned long int tmp_long;
 
       s_err = xstrtoul (name, NULL, 0, &tmp_long, NULL);
-      *g = tmp_long;
-      if (s_err == LONGINT_OVERFLOW || tmp_long > INT_MAX)
+      if (s_err != LONGINT_OK)
 	{
 	  STRTOL_FATAL_ERROR (name, _("group number"), s_err);
 	}
+      if (tmp_long > INT_MAX)
+	{
+	  error (1, 0, _("invalid group number `%s'"), name);
+	}
+      *g = tmp_long;
     }
   else
     *g = grp->gr_gid;
